@@ -247,6 +247,7 @@ pub struct ConfigTui {
     pub tui_max_addrs: Option<u8>,
     pub geoip_mmdb_file: Option<String>,
     pub tui_custom_columns: Option<String>,
+    pub tui_locale: Option<String>,
     #[serde(rename = "tui-max-samples")]
     pub deprecated_tui_max_samples: Option<usize>,
     #[serde(rename = "tui-max-flows")]
@@ -258,13 +259,14 @@ impl Default for ConfigTui {
         Self {
             tui_preserve_screen: Some(super::constants::DEFAULT_TUI_PRESERVE_SCREEN),
             tui_refresh_rate: Some(super::constants::DEFAULT_TUI_REFRESH_RATE),
-            tui_privacy_max_ttl: Some(super::constants::DEFAULT_TUI_PRIVACY_MAX_TTL),
+            tui_privacy_max_ttl: None,
             tui_address_mode: Some(super::constants::DEFAULT_TUI_ADDRESS_MODE),
             tui_as_mode: Some(super::constants::DEFAULT_TUI_AS_MODE),
             tui_custom_columns: Some(String::from(super::constants::DEFAULT_CUSTOM_COLUMNS)),
             tui_icmp_extension_mode: Some(super::constants::DEFAULT_TUI_ICMP_EXTENSION_MODE),
             tui_geoip_mode: Some(super::constants::DEFAULT_TUI_GEOIP_MODE),
             tui_max_addrs: Some(super::constants::DEFAULT_TUI_MAX_ADDRS),
+            tui_locale: None,
             geoip_mmdb_file: None,
             deprecated_tui_max_samples: None,
             deprecated_tui_max_flows: None,
@@ -294,6 +296,7 @@ pub struct ConfigThemeColors {
     pub flows_chart_text_current_color: Option<TuiColor>,
     pub flows_chart_text_non_current_color: Option<TuiColor>,
     pub samples_chart_color: Option<TuiColor>,
+    pub samples_chart_lost_color: Option<TuiColor>,
     pub help_dialog_bg_color: Option<TuiColor>,
     pub help_dialog_text_color: Option<TuiColor>,
     pub settings_dialog_bg_color: Option<TuiColor>,
@@ -307,6 +310,8 @@ pub struct ConfigThemeColors {
     pub map_info_panel_border_color: Option<TuiColor>,
     pub map_info_panel_bg_color: Option<TuiColor>,
     pub map_info_panel_text_color: Option<TuiColor>,
+    pub info_bar_bg_color: Option<TuiColor>,
+    pub info_bar_text_color: Option<TuiColor>,
 }
 
 impl Default for ConfigThemeColors {
@@ -331,6 +336,7 @@ impl Default for ConfigThemeColors {
             flows_chart_text_current_color: Some(theme.flows_chart_text_current),
             flows_chart_text_non_current_color: Some(theme.flows_chart_text_non_current),
             samples_chart_color: Some(theme.samples_chart),
+            samples_chart_lost_color: Some(theme.samples_chart_lost),
             help_dialog_bg_color: Some(theme.help_dialog_bg),
             help_dialog_text_color: Some(theme.help_dialog_text),
             settings_dialog_bg_color: Some(theme.settings_dialog_bg),
@@ -344,6 +350,8 @@ impl Default for ConfigThemeColors {
             map_info_panel_border_color: Some(theme.map_info_panel_border),
             map_info_panel_bg_color: Some(theme.map_info_panel_bg),
             map_info_panel_text_color: Some(theme.map_info_panel_text),
+            info_bar_bg_color: Some(theme.info_bar_bg),
+            info_bar_text_color: Some(theme.info_bar_text),
         }
     }
 }
@@ -373,7 +381,10 @@ pub struct ConfigBindings {
     pub toggle_freeze: Option<TuiKeyBinding>,
     pub toggle_chart: Option<TuiKeyBinding>,
     pub toggle_flows: Option<TuiKeyBinding>,
-    pub toggle_privacy: Option<TuiKeyBinding>,
+    #[serde(rename = "toggle-privacy")]
+    pub deprecated_toggle_privacy: Option<TuiKeyBinding>,
+    pub expand_privacy: Option<TuiKeyBinding>,
+    pub contract_privacy: Option<TuiKeyBinding>,
     pub toggle_map: Option<TuiKeyBinding>,
     pub expand_hosts: Option<TuiKeyBinding>,
     pub contract_hosts: Option<TuiKeyBinding>,
@@ -387,6 +398,7 @@ pub struct ConfigBindings {
     pub toggle_as_info: Option<TuiKeyBinding>,
     pub toggle_hop_details: Option<TuiKeyBinding>,
     pub quit: Option<TuiKeyBinding>,
+    pub quit_preserve_screen: Option<TuiKeyBinding>,
 }
 
 impl Default for ConfigBindings {
@@ -415,7 +427,9 @@ impl Default for ConfigBindings {
             toggle_freeze: Some(bindings.toggle_freeze),
             toggle_chart: Some(bindings.toggle_chart),
             toggle_flows: Some(bindings.toggle_flows),
-            toggle_privacy: Some(bindings.toggle_privacy),
+            deprecated_toggle_privacy: None,
+            expand_privacy: Some(bindings.expand_privacy),
+            contract_privacy: Some(bindings.contract_privacy),
             toggle_map: Some(bindings.toggle_map),
             expand_hosts: Some(bindings.expand_hosts),
             contract_hosts: Some(bindings.contract_hosts),
@@ -429,6 +443,7 @@ impl Default for ConfigBindings {
             toggle_as_info: Some(bindings.toggle_as_info),
             toggle_hop_details: Some(bindings.toggle_hop_details),
             quit: Some(bindings.quit),
+            quit_preserve_screen: Some(bindings.quit_preserve_screen),
         }
     }
 }
