@@ -20,9 +20,6 @@ mod print;
 mod report;
 mod util;
 
-// initialize the i18n system.
-rust_i18n::i18n!("locales", fallback = "en");
-
 /// Run the Trippy application.
 pub fn trippy() -> anyhow::Result<()> {
     let args = Args::parse();
