@@ -2,7 +2,6 @@ use crate::config::{Args, TuiCommandItem, TuiThemeItem};
 use crate::locale::available_locales;
 use clap::CommandFactory;
 use clap_complete::Shell;
-use itertools::Itertools;
 use std::process;
 use strum::VariantNames;
 
@@ -32,7 +31,7 @@ pub fn print_man_page() -> anyhow::Result<()> {
 }
 
 pub fn print_locales() {
-    println!("TUI locales: {}", available_locales().iter().join(", "));
+    println!("TUI locales: {}", available_locales().join(", "));
     process::exit(0);
 }
 
